/*
** File: identify.c  
** Project: ADMXRC3 module driver
** Purpose: Identify device given model, bootstrap the the device context
**          appropriately for that model.
**
** (C) Copyright Alpha Data 2010-2014
*/

#include <df.h>

#include "device.h"
#include "identify.h"
#include "model_boot.h"

boolean_t
admxrc3Identify(
  Admxrc3DeviceContext* pDevCtx,
  CoreModelType model)
{
#if defined(ADMXRC3_CUSTOM) && ADMXRC3_CUSTOM
  if (admxrc3IdentifyCustom(pDevCtx, model)) {
    return TRUE; /* Success */
  }
#endif

#if !defined(ADMXRC3_CUSTOM_ONLY) || !ADMXRC3_CUSTOM_ONLY
  switch (model) {
  case CoreModelGeneric:
    admxrc3BootstrapGeneric(pDevCtx);
    return TRUE;

  case CoreModelAdmxrc2:
    admxrc3BootstrapAdmxrc2(pDevCtx);
    return TRUE;

  case CoreModelAdpexrc5t:
    admxrc3BootstrapAdpexrc5t(pDevCtx);
    return TRUE;

  case CoreModelAdmxrc6tl:
    admxrc3BootstrapAdmxrc6tl(pDevCtx);
    return TRUE;

  case CoreModelAdmxrc6t1:
  case CoreModelAdmxrc6t1Bert:
    admxrc3BootstrapAdmxrc6t1(pDevCtx);
    return TRUE;

  case CoreModelAdmxrc6tge:
  case CoreModelAdmxrc6tgel:
    admxrc3BootstrapAdmxrc6tge(pDevCtx);
    return TRUE;

  case CoreModelAdmxrc6tadv8:
    admxrc3BootstrapAdmxrc6tadv8(pDevCtx);
    return TRUE;

  case CoreModelAdpexrc6t:
  case CoreModelAdpexrc6tBert:
  case CoreModelAdpexrc6tl:
  case CoreModelAdpexrc6tlBert:
    admxrc3BootstrapAdpexrc6t(pDevCtx);
    return TRUE;

  case CoreModelAdpexrc6tadvControl:
  case CoreModelAdpexrc6tadvTarget0:
  case CoreModelAdpexrc6tadvTarget1:
    admxrc3BootstrapAdpexrc6tadv(pDevCtx);
    return TRUE;

  case CoreModelAdmxrc7k1:
    admxrc3BootstrapAdmxrc7k1(pDevCtx);
    return TRUE;

  case CoreModelAdmxrc6tda1:
  case CoreModelAdmxrc6tda1Bert:
    admxrc3BootstrapAdmxrc6tda1(pDevCtx);
    return TRUE;

  case CoreModelAdmxrc7v1:
    admxrc3BootstrapAdmxrc7v1(pDevCtx);
    return TRUE;

  case CoreModelAdmvpx37v2:
    admxrc3BootstrapAdmvpx37v2(pDevCtx);
    return TRUE;

  case CoreModelAdmpcie7v3:
    admxrc3BootstrapAdmpcie7v3(pDevCtx);
    return TRUE;

  case CoreModelAdmxrc7z1:
    admxrc3BootstrapAdmxrc7z1(pDevCtx);
    return TRUE;

  case CoreModelAdmxrc7z2:
    admxrc3BootstrapAdmxrc7z2(pDevCtx);
    return TRUE;

  case CoreModelAdmxrcku1:
    admxrc3BootstrapAdmxrcku1(pDevCtx);
    return TRUE;

  case CoreModelAdmxrcku1at8:
    admxrc3BootstrapAdmxrcku1at8(pDevCtx);
    return TRUE;

  case CoreModelAdmxrcku1P5:
    admxrc3BootstrapAdmxrcku1(pDevCtx);
    return TRUE;

  case CoreModelAdmxrcku1P6:
    admxrc3BootstrapAdmxrcku1(pDevCtx);
    return TRUE;

  case CoreModelAdmpcieku3:
  case CoreModelAdmpcieku32nd:
    admxrc3BootstrapAdmpcieku3(pDevCtx);
    return TRUE;

  case CoreModelAdmpcie8v3:
  case CoreModelAdmpcie8v32nd:
    admxrc3BootstrapAdmpcie8v3(pDevCtx);
    return TRUE;

  case CoreModelAdmpcie8k5:
    admxrc3BootstrapAdmpcie8k5(pDevCtx);
    return TRUE;

  case CoreModelAdmad01478:
    admxrc3BootstrapAdmad01478(pDevCtx);
    return TRUE;

  case CoreModelAdmad01479:
    admxrc3BootstrapAdmad01479(pDevCtx);
    return TRUE;

  default:
    break;
  }
#endif

	return FALSE; /* Failure */
}
